# 👋 Welcome

<!-- Include Readme header -->

```{include} ../../README.md
:start-after: <!-- BEGIN-HEADER -->
:end-before: <!-- END-HEADER -->
```

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

```{grid-item-card} 🚀 Get Started
:link: intro
:link-type: doc
:link-alt: get started

Follow the instructions to set up your environment and start using `cherab-imas`.

+++
[Learn more »](intro)
```

```{grid-item-card} 🧪 Examples
:link: examples
:link-type: doc
:link-alt: examples

Here are some examples to get you started with `cherab-imas`.

+++
[Learn more »](examples)
```

```{grid-item-card} 📚 API Reference
:link: api
:link-type: doc
:link-alt: api

Access the full API reference documentation for `cherab-imas`.

+++
[Learn more »](api)
```

```{grid-item-card} 🤝 Contributing
:link: contributing
:link-type: doc
:link-alt: contributing

Learn how to contribute to the `cherab-imas` project.

+++
[Learn more »](contributing)
```

::::

```{toctree}
:hidden:
:maxdepth: 1

self
intro.md
examples.md
```

```{toctree}
:caption: Reference 📖
:hidden:
:maxdepth: 1

api.md
contributing.md
```
